==> plplot-5.13.0.tar.gz: plplot-5.13.0/doc/doxygen/html/search/defines_6.js <==
var searchData=
[
  ['f2c',['f2c',['../plplot__octaveOCTAVE__wrap_8cxx.html#a1ffa0c2ac3e8935b915b4c2abd3e52d8',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['f_5fok',['F_OK',['../plfreetype_8c.html#af837744613408b57dc3654fbc3bcf900',1,'plfreetype.c']]],
  ['faceted',['FACETED',['../plplot_8h.html#a73593859d45942fe004d7bbf925ef770',1,'plplot.h']]],
  ['false',['FALSE',['../plplotP_8h.html#aa93f0eb578d23995850d61f7d61c55c1',1,'plplotP.h']]],
  ['family_5flookup_5flen',['FAMILY_LOOKUP_LEN',['../cairo_8c.html#ab3d2121ee9cf9bfa444cc00df8af87ed',1,'cairo.c']]],
  ['fh_5ffifo',['FH_FIFO',['../plframe_8c.html#a917863370c5d178fbea21f9e6041dca9',1,'plframe.c']]],
  ['filecast',['FILECAST',['../plframe_8c.html#a4c167b592b60cb413b3e1ae4a9a4204c',1,'plframe.c']]],
  ['font_5fshift_5foffset',['FONT_SHIFT_OFFSET',['../svg_8c.html#a0f5a2675e26014effd9cc8637c2013f4',1,'svg.c']]],
  ['font_5fshift_5fratio',['FONT_SHIFT_RATIO',['../svg_8c.html#a62d1795b313cc9ccaa2b5832585a8251',1,'svg.c']]],
  ['font_5fsize_5fratio',['FONT_SIZE_RATIO',['../svg_8c.html#a7cc16d77694f2909bc9f85f30a36d963',1,'svg.c']]],
  ['form_5flen',['FORM_LEN',['../plcont_8c.html#a43af5e201d862de6fd3c6a1b39255774',1,'plcont.c']]],
  ['format_5flen',['FORMAT_LEN',['../plbox_8c.html#a222e64cfd1348e6bf177935a26f7c713',1,'plbox.c']]],
  ['fpos_5ft',['FPOS_T',['../plplotP_8h.html#a7e6aade5ce3529e2eb65b16311015e9b',1,'plplotP.h']]],
  ['free_5fmem',['free_mem',['../plplotP_8h.html#af65d2391cbbf6daaedb72e9fe83078c6',1,'plplotP.h']]],
  ['freeprocarg',['FreeProcArg',['../plframe_8c.html#a068062d21d1a20efd96f88a4da8a39fb',1,'plframe.c']]],
  ['fuzz_5fepsilon',['FUZZ_EPSILON',['../plctrl_8c.html#a0780049ead3dd9de47097bc8b4a9eff0',1,'plctrl.c']]],
  ['fuzzy_5frange_5fcheck',['fuzzy_range_check',['../plctrl_8c.html#a1cb724db4a53d59ca36f9024da8cdf87',1,'plctrl.c']]]
];

==> plplot-5.15.0.tar.gz: plplot-5.15.0/doc/doxygen/html/search/defines_6.js <==
var searchData=
[
  ['f2c',['f2c',['../plplot__octaveOCTAVE__wrap_8cxx.html#a1ffa0c2ac3e8935b915b4c2abd3e52d8',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['f_5fok',['F_OK',['../plfreetype_8c.html#af837744613408b57dc3654fbc3bcf900',1,'plfreetype.c']]],
  ['faceted',['FACETED',['../plplot_8h.html#a73593859d45942fe004d7bbf925ef770',1,'plplot.h']]],
  ['false',['FALSE',['../plplotP_8h.html#aa93f0eb578d23995850d61f7d61c55c1',1,'plplotP.h']]],
  ['family_5flookup_5flen',['FAMILY_LOOKUP_LEN',['../cairo_8c.html#ab3d2121ee9cf9bfa444cc00df8af87ed',1,'FAMILY_LOOKUP_LEN():&#160;cairo.c'],['../psttf_8cc.html#ab3d2121ee9cf9bfa444cc00df8af87ed',1,'FAMILY_LOOKUP_LEN():&#160;psttf.cc']]],
  ['fh_5ffifo',['FH_FIFO',['../plframe_8c.html#a917863370c5d178fbea21f9e6041dca9',1,'plframe.c']]],
  ['filecast',['FILECAST',['../plframe_8c.html#a4c167b592b60cb413b3e1ae4a9a4204c',1,'plframe.c']]],
  ['font_5fshift_5foffset',['FONT_SHIFT_OFFSET',['../svg_8c.html#a0f5a2675e26014effd9cc8637c2013f4',1,'svg.c']]],
  ['font_5fshift_5fratio',['FONT_SHIFT_RATIO',['../svg_8c.html#a62d1795b313cc9ccaa2b5832585a8251',1,'svg.c']]],
  ['font_5fsize_5fratio',['FONT_SIZE_RATIO',['../svg_8c.html#a7cc16d77694f2909bc9f85f30a36d963',1,'svg.c']]],
  ['form_5flen',['FORM_LEN',['../plcont_8c.html#a43af5e201d862de6fd3c6a1b39255774',1,'plcont.c']]],
  ['format_5flen',['FORMAT_LEN',['../plbox_8c.html#a222e64cfd1348e6bf177935a26f7c713',1,'plbox.c']]],
  ['fpos_5ft',['FPOS_T',['../plplotP_8h.html#a7e6aade5ce3529e2eb65b16311015e9b',1,'plplotP.h']]],
  ['free_5fmem',['free_mem',['../plplotP_8h.html#af65d2391cbbf6daaedb72e9fe83078c6',1,'plplotP.h']]],
  ['freeprocarg',['FreeProcArg',['../plframe_8c.html#a068062d21d1a20efd96f88a4da8a39fb',1,'plframe.c']]],
  ['fuzz_5fepsilon',['FUZZ_EPSILON',['../plctrl_8c.html#a0780049ead3dd9de47097bc8b4a9eff0',1,'plctrl.c']]],
  ['fuzzy_5frange_5fcheck',['fuzzy_range_check',['../plctrl_8c.html#a1cb724db4a53d59ca36f9024da8cdf87',1,'plctrl.c']]]
];
